intelmq.bots.parsers.alienvault package — intelmq 3.1.0.alpha1 documentation

# intelmq.bots.parsers.alienvault package

## Submodules

## intelmq.bots.parsers.alienvault.parser module

class intelmq.bots.parsers.alienvault.parser.AlienVaultParserBot(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.ParserBot`

  Parse data from the AlienVault API

  parse_line(row, report)

    A generator which can yield one or more messages contained in line.

    Report has the full message, thus you can access some metadata. Override for your use.

intelmq.bots.parsers.alienvault.parser.BOT

  alias of `intelmq.bots.parsers.alienvault.parser.AlienVaultParserBot`

## intelmq.bots.parsers.alienvault.parser_otx module

Events are gathered based on user subscriptions in AlienVault OTX The data structure is described in detail here: https://github.com/AlienVault-Labs/OTX-Python-SDK/blob/master/ howto_use_python_otx_api.ipynb

class intelmq.bots.parsers.alienvault.parser_otx.AlienVaultOTXParserBot(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.ParserBot`

  Parse data from the AlienVault OTX API

  parse(report: intelmq.lib.message.Report)

    A basic JSON parser. Assumes a list of objects as input to be yield.

  parse_line(pulse, report)

    A generator which can yield one or more messages contained in line.

    Report has the full message, thus you can access some metadata. Override for your use.

  recover_line(line: dict) → str

    Reverse of parse for JSON pulses.

    Recovers a fully functional report with only the problematic pulse.

intelmq.bots.parsers.alienvault.parser_otx.BOT

  alias of `intelmq.bots.parsers.alienvault.parser_otx.AlienVaultOTXParserBot`

## Module contents